## Understanding **must** precede advice
When beginning a conversation, the goal should be understanding, not problem solving. You should aim to make sure there's a *mutual understanding* of the situation before attempting to problem solve. Problem solving and advice should *only* begin when both people feel totally understood, and heard.
# Skills
There are a few skills that can massively contribute to a healthy relationship. It takes work and practice to refine them.
## Putting Your Feelings into Words
When people are able to find the right images, phrases, metaphors, and words to adequately describe our feelings, there's a kind of "resolution" that comes of it, an easing of tension. In conversation, focusing on finding the right way to explain your feelings can make the conversation more intimate, and more productive, because you can convey your feelings to the other person in a more impactful way.
## Asking Open-Ended Questions
The ability to ask open ended questions can help the other person explore their feelings by asking open-ended questions. This can be done by asking targeted questions, looking to understand their feelings about something, and by making specific statements that encourage the other person to expand on a statement further.
## Expressing Empathy
Empathy *is not easy*. In a difficult conversation, it's important to try to learn more about, explore, and learn more about another person's thoughts, feelings, and needs. Empathy communicates to the other person that their thoughts, feelings, and needs make sense to you, and that you understand them. It doesn't necessarily mean you agree, but it means showing them that their perception of the situation is valid. You can have your own perception of the situation that's different from theirs, but both of your perceptions can be valid.

---

# Crucial Conversations
Below are my notes and thoughts from reading the book *Crucial Conversations.

The fundamental idea behind the book is that:
> The root cause of many ... human problems lies in how people behave when we disagree about high-stakes, emotional issues.

You know you're getting into a crucial conversation as opposed to a normal conversation when:
- Opinions vary, people feel differently about things.
- The stakes are high, the outcome of the conversation matters.
- Emotions are high, people feel strongly about the outcome.

One important factor in problem resolution is the time that passes between when the problem emerges, and when resolution is attempted. The impact of the issues, and the difficulty of resolution grow when the issue is left unresolved. It can lead to gossiping, mistrust, and resentment. 

It's important to try to resolve problems *quickly* after they are identified.

### How do we handle crucial conversations?
There are 3 broad options:
- We can avoid them entirely.
- We can face them and handle it poorly.
- We can face them and handle it well.

While only one of these options reliably leads to an effective outcome, you'll often find that we often fall back to the first two because of the fear that engagement will make the issue worse. 

*personal note*: Humans inherently dislike being uncomfortable, the root instinct to avoid immediate discomfort in any way is natural . But in so many parts of life, if you push through that, the outcome will be very positive. Try to be mindful of anything that makes you uncomfortable, and ask yourself, "will my life improve if I do this hard thing?"

If you fail to discuss these issues with other people, *those issues will become the lens through which you see them*, which will show up in the way you treat the other person.

We generally handle important conversations *poorly*, strong emotions make people worse at communicating effectively, not better. Our natural instincts are to push back against that communication because it's hard, and it triggers our fight or flight instincts. This means we won't be receptive to new information, and we'll likely respond in a way that's not irrational and hurts the situation for both parties. It usually takes conscious effort to be mindful of your thoughts and feelings, process them fully and rationally, then respond to the other party in a rational way.

*personal note*: When we get emotional, the *limbic system* in our brain begins to take control. We stop being rational, and we literally do not process things with the same amount of brainpower that we'd use normally. This is why it's so important to recognize when you're emotional, and why it's important to avoid letting conversations get ruled by emotion.

### Dialogue
A healthy conversation should involve two way communication. You need to make sure the other person is given the space to make themself understood. 

When meaning and ideas can flow freely, people are often more receptive to ideas and change. When everyone can contribute their feelings to the discussion, people involved can form a clearer picture of the circumstances, and when everyone has a clear understanding, then they're more likely to personally commit to the outcome of the discussion.
### Topics
Difficult conversations are most successful when they're focused on a single issue. Because human interactions are inherently complex, focusing **a conversation on a single topic takes effort**. 

When faced with the time to pick a topic, there are a few common mistakes:
- Picking an easier topic over the hard topic: It's natural to have a bias to choose a topic you think you can win with. That usually means picking an easier topic than the root issue.
- Choosing a more recent event over the most important one: We tend to focus on the most recent event or behavior rather than the one that matters the most. This often happens because you remember recent events more clearly, and you don't want to be accused of "dredging up ancient history".

Making these mistakes can lead to fairly predictable results: you end up having the wrong conversation and not addressing the actual issue. **A few ways ways to identify that you're having the wrong conversation include**:
- **Your emotions escalate**: When you're having the wrong conversation, even if the conversation is going well, you'll probably begin to notice frustration building as the conversation progresses, because there's something important that needs to be addressed.
- **You walk away skeptical**: If you find yourself feeling like real change will not take place, or that you got to an agreement but doubt that the changes made will solve the real problem, you might have missed addressing the real problem entirely.
- **You feel deja vu**: If you feel like you're repeating a conversation with the same people again, the problem is not them, it's you. You're having the wrong conversation about the wrong topic, and so the problem isn't fixed.

One of the best ways to ensure you're talking about the right topic is to get good at noticing when you're actually talking about the wrong one.

#### Choosing the right topic
There are a few skills that can help you figure out the right issue, and in turn lead to you having the right conversation.

**Unbundling**
There are three levels of conversation you may need to have about the issue itself, and a 4th relating to the *process* of the conversation.
- **Content**: The first time a problem comes up, talk about the content - the immediate pain. *If the action or the immediate consequences are the issue, you have a content problem*. This is for when it's the first time something has happened.
- **Pattern**: The next time a problem comes up, it means a pattern is starting to develop, or already has. It can be difficult to determine when something's a pattern, and when it's not, but it's important to address patterns early, before they're entrenched, and the problem becomes more difficult to address. As a general rule, the first time something happens, it's an incident. The second time, it may be coincidence. The third time, it is a pattern.
- **Relationship**: As problems continue, they can begin to impact the relationship. Relationship issues get to deeper concerns about *trust*, *competence*, or *respect*. For example, we may begin to question whether we can trust a person to keep commitments, or begin to doubt someone's technical abilities.





